netapp_ontap.models.data_engine_governance_file_preview_file_content_request_file API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.data_engine_governance_file_preview_file_content_request_file`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class DataEngineGovernanceFilePreviewFileContentRequestFileSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the DataEngineGovernanceFilePreviewFileContentRequestFile object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `format: str GET POST PATCH`

    Format of the file.

    Valid choices:

    - pdf
    - docx
    - txt
    - csv
    - json
    - map
    - js
    - doc
    - xlsx
    - css
    - xls
  `path: str GET POST PATCH`

    Path to the downloaded file. This is present when the job is completed.

    Example: /downloaded_folder/file1.pdf

  `uuid: str GET POST PATCH`

    UUID of the entity.

    Example: 12c9e267-23be-22e9-81d5-00xx986138f7